@@ -28,10 +28,11 @@ __author__       = 'Rolv-Arild Braaten'
 # __email__        = ''
 __copyright__    = 'Copyright (c) 2020 Rolv-Arild Braaten'
 __license__      = 'Apache License 2.0'
-__version__      = '0.1.7'
+__version__      = '0.1.8'
 __url__          = 'https://github.com/Rolv-Arild/python-ballchasing'
 __download_url__ = 'https://pypi.python.org/pypi/python-ballchasing'
 __description__  = 'A Python wrapper around the Ballchasing API'
 
 from .api import Api                        # noqa
-import enums
+from .enums import Playlist, Rank, Season, MatchResult, ReplaySortBy, GroupSortBy, SortDir, Visibility, \
+    PlayerIdentification, TeamIdentification, Map
